#!/usr/bin/python

# Hygrosens Sensor Reading Example
# Copyright 2005 by Brian C. Lane
# All Rights Reserved
# Licensed under GPL v2, see COPYRIGHT and COPYING files
#
# Reads 1 pass of the sensor output from a Hygrosens sensor and outputs it in
# a human readable format
import sys,os

try:
    from hygrosens import *
except:
    sys.stderr.write("Error importing Hygrosens library, is it installed?\n")
    sys.exit(-1)

try:    
    sensors = hygrosens(debug=0,port='/dev/ttyS0',timeout=10)
except:
    sys.stderr.write("Error opening the Hygosens device\n")
    raise
    sys.exit(-1)
    
    
# Read the sensors as a hash of sensor info. The key is the channel number
# Hash contains:
#   channel
#   type
#   family
#   serial
#   value
result = sensors.read_all()

# Display the results in the channel order
result_keys = result.keys()
result_keys.sort()
for key in result_keys:
#    print result[key]
    if result[key]['type'] == 1:
        # Temperature in degrees C
        sys.stdout.write( "Temperature    : %0.2fC\n" % (result[key]['value']))
    elif result[key]['type'] == 2:
        # Relative Humidity (0-100%)
        sys.stdout.write( "Rel. Humidity  : %0.2f%%\n" % (result[key]['value']))
    elif result[key]['type'] == 3:
        # Air Pressure in Pascals?
        sys.stdout.write( "Pressure       : %0.2f\n" % (result[key]['value']))       
    elif result[key]['type'] == 10:
        # Light Sensor
        sys.stdout.write( "Light Level    : %d\n" % (result[key]['value']))
    elif result[key]['type'] == 0x53:
        # Dew Point
        sys.stdout.write( "Dew Point      : %0.2fC\n" % (result[key]['value']))
    elif result[key]['type'] == 0x55:
        # Absolute Humidity
        sys.stdout.write( "Abs. Humidity  : %0.2f%%\n" % (result[key]['value']))

